@@ -1,7 +1,8 @@
 #' Create a list of tokens
 #'
 #' @param tbl A tibble of tokens out of \code{tokenize()}.
-#' @param token_field Column name that contains tokens.
+#' @param token_field <[`data-masked`][rlang::args_data_masking]>
+#' Column name that contains tokens.
 #' @param pos_field Feature name that will be kept as the names
 #' of tokens. If you don't need them, give a `NULL` for this argument.
 #' @param nm Names of returned list.
@@ -12,8 +13,8 @@
 #' \dontrun{
 #' tokenize(
 #'   data.frame(
-#'     doc_id = seq_along(audubon::polano[5:8]),
-#'     text = audubon::polano[5:8]
+#'     doc_id = seq_along(ginga[5:8]),
+#'     text = ginga[5:8]
 #'   )
 #' ) |>
 #'   prettify(col_select = "POS1") |>
@@ -23,8 +24,8 @@ as_tokens <- function(tbl,
                       token_field = "token",
                       pos_field = get_dict_features()[1],
                       nm = NULL) {
-  token_field <- enquo(token_field)
-  col_names <- rlang::as_name("doc_id")
+  token_field <- as_name(enquo(token_field))
+  col_names <- as_name("doc_id")
 
   if (is.null(nm)) {
     if (is.factor(tbl[[col_names]])) {
@@ -35,18 +36,12 @@ as_tokens <- function(tbl,
   }
 
   if (is.null(pos_field)) {
-    tbl %>%
-      dplyr::group_by(.data[[col_names]]) %>%
-      dplyr::group_map(function(df, grp) {
-        dplyr::pull(df, !!token_field)
-      }) %>%
+    tbl[[token_field]] %>%
+      split(tbl[[col_names]]) %>%
       purrr::set_names(nm)
   } else {
-    tbl %>%
-      dplyr::group_by(.data[[col_names]]) %>%
-      dplyr::group_map(function(df, grp) {
-        dplyr::pull(df, !!token_field, pos_field)
-      }) %>%
+    purrr::set_names(tbl[[token_field]], tbl[[pos_field]]) %>%
+      split(tbl[[col_names]]) %>%
       purrr::set_names(nm)
   }
 }
