@@ -10,8 +10,8 @@
 #include "char_property.h"
 #include "common.h"
 #include "dictionary.h"
-#include "dictionary_rewriter.h"
-#include "feature_index.h"
+// #include "dictionary_rewriter.h"
+// #include "feature_index.h"
 #include "iconv_utils.h"
 #include "mmap.h"
 #include "param.h"
